@@ -29,13 +29,16 @@ import textwrap
 import platform
 import importlib
 import operator
+import datetime
+import subprocess
+import re
 
 import pytest
 import packaging.version
 
 import path
 from path import TempDir
-from path import CaseInsensitivePattern as ci
+from path import matchers
 from path import SpecialResolver
 from path import Multi
 
@@ -47,7 +50,7 @@ def p(**choices):
     return choices[os.name]
 
 
-@pytest.fixture(autouse=True, params=[path.Path, path.FastPath])
+@pytest.fixture(autouse=True, params=[path.Path])
 def path_class(request, monkeypatch):
     """
     Invoke tests on any number of Path classes.
@@ -233,6 +236,27 @@ class TestBasics:
         assert res2 == 'foo/bar'
 
 
+class TestPerformance:
+    def test_import_time(self, monkeypatch):
+        """
+        Import of path.py should take less than 100ms.
+
+        Run tests in a subprocess to isolate from test suite overhead.
+        """
+        cmd = [
+            sys.executable,
+            '-m', 'timeit',
+            '-n', '1',
+            '-r', '1',
+            'import path',
+        ]
+        res = subprocess.check_output(cmd, universal_newlines=True)
+        dur = re.search(r'(\d+) msec per loop', res).group(1)
+        limit = datetime.timedelta(milliseconds=100)
+        duration = datetime.timedelta(milliseconds=int(dur))
+        assert duration < limit
+
+
 class TestSelfReturn:
     """
     Some methods don't necessarily return any value (e.g. makedirs,
@@ -385,16 +409,12 @@ class TestScratchDir:
                 except Exception:
                     pass
 
-    @pytest.mark.xfail(
-        platform.system() == 'Linux' and path.PY2,
-        reason="Can't decode bytes in FS. See #121",
-    )
     @pytest.mark.xfail(
         mac_version('10.13'),
         reason="macOS disallows invalid encodings",
     )
     @pytest.mark.xfail(
-        platform.system() == 'Windows' and path.PY3,
+        platform.system() == 'Windows',
         reason="Can't write latin characters. See #133",
     )
     def test_listdir_other_encoding(self, tmpdir):
@@ -831,6 +851,20 @@ class TestMergeTree:
         assert self.subdir_b.isdir()
         assert self.subdir_b.listdir() == [self.subdir_b / self.test_file.name]
 
+    def test_only_newer(self):
+        """
+        merge_tree should accept a copy_function in which only
+        newer files are copied and older files do not overwrite
+        newer copies in the dest.
+        """
+        target = self.subdir_b / 'testfile.txt'
+        target.write_text('this is newer')
+        self.subdir_a.merge_tree(
+            self.subdir_b,
+            copy_function=path.only_newer(shutil.copy2),
+        )
+        assert target.text() == 'this is newer'
+
 
 class TestChdir:
     def test_chdir_or_cd(self, tmpdir):
@@ -999,10 +1033,10 @@ class TestPatternMatching:
         p = Path(tmpdir)
         (p / 'sub').mkdir()
         (p / 'File').touch()
-        assert p.listdir(ci('S*')) == [p / 'sub']
-        assert p.listdir(ci('f*')) == [p / 'File']
-        assert p.files(ci('S*')) == []
-        assert p.dirs(ci('f*')) == []
+        assert p.listdir(matchers.CaseInsensitive('S*')) == [p / 'sub']
+        assert p.listdir(matchers.CaseInsensitive('f*')) == [p / 'File']
+        assert p.files(matchers.CaseInsensitive('S*')) == []
+        assert p.dirs(matchers.CaseInsensitive('f*')) == []
 
     def test_walk_case_insensitive(self, tmpdir):
         p = Path(tmpdir)
@@ -1011,7 +1045,7 @@ class TestPatternMatching:
         (p / 'sub1' / 'foo' / 'bar.Txt').touch()
         (p / 'sub2' / 'foo' / 'bar.TXT').touch()
         (p / 'sub2' / 'foo' / 'bar.txt.bz2').touch()
-        files = list(p.walkfiles(ci('*.txt')))
+        files = list(p.walkfiles(matchers.CaseInsensitive('*.txt')))
         assert len(files) == 2
         assert p / 'sub2' / 'foo' / 'bar.TXT' in files
         assert p / 'sub1' / 'foo' / 'bar.Txt' in files
@@ -1199,5 +1233,22 @@ class TestMultiPath:
         assert path == input
 
 
-if __name__ == '__main__':
-    pytest.main()
+def test_no_dependencies():
+    """
+    Path.py guarantees that the path module can be
+    transplanted into an environment without any dependencies.
+    """
+    cmd = [
+        sys.executable,
+        '-S',
+        '-c', 'import path',
+    ]
+    subprocess.check_call(cmd)
+
+
+def test_version():
+    """
+    Under normal circumstances, path should present a
+    __version__.
+    """
+    assert re.match(r'\d+\.\d+.*', path.__version__)
